import re
from typing import Any
import pandas as pd
import os


def read_csv(file_path: str):
    if not file_path or not os.path.isfile(file_path):
        raise FileNotFoundError(f"Invalid file path: {file_path}")
    return pd.read_csv(file_path).to_dict(orient="records")


def write_csv(file_path: str, row: list[dict[str, Any]]):
    if not file_path:
        raise ValueError(f"file path can not be empty")
    if not row:
        return
    need_write_head = False
    if not os.path.exists(file_path):
        need_write_head = True
    pd.DataFrame(row).to_csv(file_path, index=False, mode="a", header=need_write_head)



import logging
import os


def get_logger(name):
    if name:
        name = deal_name(name)  # 假设deal_name是定义好的函数
    else:
        name = __name__
    logger = logging.getLogger(name)
    # 检查logger是否已有handlers，避免重复添加
    if not logger.handlers:
        logger.setLevel(logging.DEBUG)
        handler = logging.StreamHandler()
        handler.setLevel(logging.DEBUG)
        formatter = logging.Formatter(
            "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
        )
        handler.setFormatter(formatter)
        logger.addHandler(handler)
    return logger


def deal_name(name: str):
    folder, filename = os.path.split(name)
    base_name = os.path.splitext(filename)[0]
    folder_name = os.path.basename(folder)
    # 组合结果
    if filename.endswith(".py"):
        return f"{folder_name}-{base_name}"
    return name



import asyncio
from enum import Enum
import random
from tkinter import NO
from playwright.async_api import Playwright
from playwright_stealth import stealth_async
import log

logger = log.get_logger(__name__)


class Browser(Enum):
    WEBKIT = "webkit"
    FIREFOX = "firefox"
    CHROME = "chrome"


async def scroll_bottom(
    page, min_scroll=800, max_scroll=1000, min_scrolls=1, max_scrolls=5
):
    scrolls = random.randint(min_scrolls, max_scrolls)
    for _ in range(scrolls):
        scroll_distance = random.randint(min_scroll, max_scroll)
        direction = random.choice([-1, 1])  # 随机选择滚动方向
        await page.mouse.wheel(0, scroll_distance * direction)
        await asyncio.sleep(random.uniform(0.5, 1))

    # 滚动到页面最底端
    await page.evaluate("window.scrollTo(0, document.body.scrollHeight);")
    await asyncio.sleep(random.uniform(0.5, 1))  # 等待一段时间，模拟人类行为
    await page.evaluate("window.scrollTo(0, 0);")


async def get_page(
    p: Playwright,
    url: str,
    engine: Browser = Browser.WEBKIT,
    max_wait: int = 5 * 60 * 1000,
    is_remote: bool = True,
    headless: bool = False,
    playwright_remote_url: str = "",
):
    if not is_remote and not playwright_remote_url:
        logger.error("Playwright remote url is empty")
        raise ValueError("Playwright remote url is empty")
    if not p:
        logger.error("Playwright is empty")
        raise ValueError("Playwright is empty")
    if not url:
        logger.error("URL is empty")
        raise ValueError("URL is empty")
    logger.info(f"start spider URL {url}")
    if engine.value == "chrome":
        if is_remote:
            browser = await p.chromium.connect(playwright_remote_url)
        else:
            browser = await p.chromium.launch(headless=headless)
    elif engine.value == "firefox":
        if is_remote:
            browser = await p.firefox.connect(playwright_remote_url)
        else:
            browser = await p.firefox.launch(headless=headless)
    else:
        if is_remote:
            browser = await p.webkit.connect(playwright_remote_url)
        else:
            browser = await p.webkit.launch(headless=headless)
    content = await browser.new_context()
    content.set_default_timeout(max_wait)
    content.set_default_navigation_timeout(max_wait)
    page = await content.new_page()
    await stealth_async(page)
    await page.goto(url)
    return browser, page, content
